@@ -112,8 +112,19 @@ import aws_cdk.aws_stepfunctions
 import aws_cdk.core
 
 
-class EventsRuleToStepFunction(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, jsii_type="@aws-solutions-constructs/aws-events-rule-step-function.EventsRuleToStepFunction"):
-    def __init__(self, scope: aws_cdk.core.Construct, id: str, *, event_rule_props: aws_cdk.aws_events.RuleProps, state_machine_props: aws_cdk.aws_stepfunctions.StateMachineProps) -> None:
+class EventsRuleToStepFunction(
+    aws_cdk.core.Construct,
+    metaclass=jsii.JSIIMeta,
+    jsii_type="@aws-solutions-constructs/aws-events-rule-step-function.EventsRuleToStepFunction",
+):
+    def __init__(
+        self,
+        scope: aws_cdk.core.Construct,
+        id: str,
+        *,
+        event_rule_props: aws_cdk.aws_events.RuleProps,
+        state_machine_props: aws_cdk.aws_stepfunctions.StateMachineProps,
+    ) -> None:
         """
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
@@ -127,7 +138,9 @@ class EventsRuleToStepFunction(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta,
         summary:
         :summary:: Constructs a new instance of the EventsRuleToStepFunction class.
         """
-        props = EventsRuleToStepFunctionProps(event_rule_props=event_rule_props, state_machine_props=state_machine_props)
+        props = EventsRuleToStepFunctionProps(
+            event_rule_props=event_rule_props, state_machine_props=state_machine_props
+        )
 
         jsii.create(EventsRuleToStepFunction, self, [scope, id, props])
 
@@ -147,9 +160,21 @@ class EventsRuleToStepFunction(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta,
         return jsii.get(self, "stateMachine")
 
 
-@jsii.data_type(jsii_type="@aws-solutions-constructs/aws-events-rule-step-function.EventsRuleToStepFunctionProps", jsii_struct_bases=[], name_mapping={'event_rule_props': 'eventRuleProps', 'state_machine_props': 'stateMachineProps'})
-class EventsRuleToStepFunctionProps():
-    def __init__(self, *, event_rule_props: aws_cdk.aws_events.RuleProps, state_machine_props: aws_cdk.aws_stepfunctions.StateMachineProps) -> None:
+@jsii.data_type(
+    jsii_type="@aws-solutions-constructs/aws-events-rule-step-function.EventsRuleToStepFunctionProps",
+    jsii_struct_bases=[],
+    name_mapping={
+        "event_rule_props": "eventRuleProps",
+        "state_machine_props": "stateMachineProps",
+    },
+)
+class EventsRuleToStepFunctionProps:
+    def __init__(
+        self,
+        *,
+        event_rule_props: aws_cdk.aws_events.RuleProps,
+        state_machine_props: aws_cdk.aws_stepfunctions.StateMachineProps,
+    ) -> None:
         """
         :param event_rule_props: User provided eventRuleProps to override the defaults. Default: - None
         :param state_machine_props: User provided StateMachineProps to override the defaults. Default: - None
@@ -157,11 +182,15 @@ class EventsRuleToStepFunctionProps():
         summary:
         :summary:: The properties for the EventsRuleToStepFunction Construct
         """
-        if isinstance(event_rule_props, dict): event_rule_props = aws_cdk.aws_events.RuleProps(**event_rule_props)
-        if isinstance(state_machine_props, dict): state_machine_props = aws_cdk.aws_stepfunctions.StateMachineProps(**state_machine_props)
+        if isinstance(event_rule_props, dict):
+            event_rule_props = aws_cdk.aws_events.RuleProps(**event_rule_props)
+        if isinstance(state_machine_props, dict):
+            state_machine_props = aws_cdk.aws_stepfunctions.StateMachineProps(
+                **state_machine_props
+            )
         self._values = {
-            'event_rule_props': event_rule_props,
-            'state_machine_props': state_machine_props,
+            "event_rule_props": event_rule_props,
+            "state_machine_props": state_machine_props,
         }
 
     @builtins.property
@@ -171,7 +200,7 @@ class EventsRuleToStepFunctionProps():
         default
         :default: - None
         """
-        return self._values.get('event_rule_props')
+        return self._values.get("event_rule_props")
 
     @builtins.property
     def state_machine_props(self) -> aws_cdk.aws_stepfunctions.StateMachineProps:
@@ -180,7 +209,7 @@ class EventsRuleToStepFunctionProps():
         default
         :default: - None
         """
-        return self._values.get('state_machine_props')
+        return self._values.get("state_machine_props")
 
     def __eq__(self, rhs) -> bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -189,7 +218,9 @@ class EventsRuleToStepFunctionProps():
         return not (rhs == self)
 
     def __repr__(self) -> str:
-        return 'EventsRuleToStepFunctionProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
+        return "EventsRuleToStepFunctionProps(%s)" % ", ".join(
+            k + "=" + repr(v) for k, v in self._values.items()
+        )
 
 
 __all__ = [
