@@ -18,7 +18,12 @@ import aws_cdk.core._jsii
 import aws_solutions_constructs.core._jsii
 import constructs._jsii
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-solutions-constructs/aws-events-rule-step-function", "1.47.0", __name__[0:-6], "aws-events-rule-step-function@1.47.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load(
+    "@aws-solutions-constructs/aws-events-rule-step-function",
+    "1.48.0",
+    __name__[0:-6],
+    "aws-events-rule-step-function@1.48.0.jsii.tgz",
+)
 
 __all__ = [
     "__jsii_assembly__",
